Auxiliary modules — GromacsWrapper 0.6.1 documentation

# Auxiliary modules

A number of small python modules are currently bundled with GromacsWrapper as they have proven useful in the context of which the main package is being used. However, GromacsWrapper does not depend on them and they could be safely ignored (and might be removed if we ever get to a 1.0 release...).

- `numkit` — Numerical analysis toolkit
  - `numkit.fitting` — Fitting data
  - `numkit.timeseries` — Time series manipulation and analysis
  - `numkit.integration` — Numerical integration of data
  - `numkit.observables` — Observables as quantities with errors
- `vmd` — Remote Tcl commands in VMD
  - VMD control
- `staging` — Staging of input/output files on a queuing system
  - `staging` — Staging module overview
  - `staging.SunGridEngine` — staging class for SunGridEngine
  - `staging.Local` — staging class for running local jobs